float4 BaseColor;
float Diffuse;
float4 Ambient;
float4 Specular;
float SpecularPower;
float Emissive;
float3 LightDir;
float3 ViewDir;
texture ColorMap;
texture AlphaMap;

sampler ColorMapSampler = sampler_state
{
	Texture = <ColorMap>;
};

sampler AlphaMapSampler = sampler_state
{
	Texture = <AlphaMap>;
};

struct VS_OUTPUT
{
	float4 Pos : POSITION;
	float4 Color : COLOR0;
	float3 Normal : TEXCOORD0;
	float2 TexCoord : TEXCOORD1;
};

/// Shader to render TR4 rooms like the tomb4.exe engine
/// In the material settings, set shader to "Blinn" and check "Vertex color".
/// Transparency is not emulated.
/// Works in conjunction with a modified version of vs_c.fx
float4 PS(VS_OUTPUT In) : COLOR0
{
	float4 tex_col = tex2D(ColorMapSampler, In.TexCoord);
	float4 alpha_col = tex2D(AlphaMapSampler, In.TexCoord);
	float3 Norm = normalize(In.Normal);
	float dif_coef = dot(Norm, LightDir);
	
	float3 Reflect = normalize(2 * dif_coef * Norm - LightDir);
	float spc_coef = pow(saturate(dot(Reflect, ViewDir)), SpecularPower);

	float4 col;
	col.a = tex_col.a; /// Retain original texture's alpha. 
	
	/// tomb4.exe shades rooms as follows :			
	if (In.Color.r > 0.5)
		col.r = tex_col.r + (0.5 * (In.Color.r - 0.5));
	else 
		col.r = tex_col.r * (2 * In.Color.r);

	if (In.Color.g > 0.5)
		col.g = tex_col.g + (0.5 * (In.Color.g - 0.5));
	else 
		col.g = tex_col.g * (2 * In.Color.g);

	if (In.Color.b > 0.5)
		col.b = tex_col.b + (0.5 * (In.Color.b - 0.5));
	else 
		col.b = tex_col.b * (2 * In.Color.b);

	return saturate(col);
}

